diff lisp/emacs-lisp/bytecomp.el @ 90104:a01e7a9f1659

Revision: miles@gnu.org--gnu-2005/emacs--unicode--0--patch-14 Update unicode-branch version numbers and ChangeLog file names 2005-02-12 Miles Bader <miles@gnu.org> * etc/TODO, etc/PROBLEMS, etc/NEWS: Replace references to Emacs version "22" with "23". 2005-02-12 Miles Bader <miles@gnu.org> * lisp/version.el (emacs-version): Change to "23.0.0". * lisp/descr-text.el (describe-char-unidata-list): Replace references to Emacs version "22" with "23". * lisp/emacs-lisp/bytecomp.el (byte-compile-fix-header) (byte-compile-insert-header): Likewise. * lisp/international/mule.el (charset-list, set-coding-priority) (ignore-relative-composition): Likewise. * lisp/international/mule-util.el (detect-coding-with-priority): Likewise. * lisp/international/mule-diag.el: Likewise. * lisp/international/mule-cmds.el (language-info-custom-alist): Likewise. * lisp/international/codepage.el (codepage-setup): Likewise. 2005-02-13 Miles Bader <miles@gnu.org> Rename unicode-branch-specific ChangeLog files to "ChangeLog.unicode" from "ChangeLog.22"
author Miles Bader <miles@gnu.org>
date Mon, 14 Feb 2005 03:40:07 +0000
parents 3ebd9bdb4fe5
children e330fedc9152
line wrap: on
line diff
--- a/lisp/emacs-lisp/bytecomp.el	Sun Feb 13 07:19:08 2005 +0000
+++ b/lisp/emacs-lisp/bytecomp.el	Mon Feb 14 03:40:07 2005 +0000
@@ -1,7 +1,7 @@
 ;;; bytecomp.el --- compilation of Lisp code into byte code
 
 ;; Copyright (C) 1985, 1986, 1987, 1992, 1994, 1998, 2000, 2001, 2002,
-;;   2003, 2004  Free Software Foundation, Inc.
+;;   2003, 2004, 2005  Free Software Foundation, Inc.
 
 ;; Author: Jamie Zawinski <jwz@lucid.com>
 ;;	Hallvard Furuseth <hbf@ulrik.uio.no>
@@ -1845,9 +1845,9 @@
 		";;; and therefore cannot be loaded into Emacs 21 or earlier.\n")
 	;; Replace "19" or "19.29" with "22", twice.
 	(re-search-forward "19\\(\\.[0-9]+\\)")
-	(replace-match "22")
+	(replace-match "23")
 	(re-search-forward "19\\(\\.[0-9]+\\)")
-	(replace-match "22")
+	(replace-match "23")
 	;; Now compensate for the change in size,
 	;; to make sure all positions in the file remain valid.
 	(setq delta (- (point-max) old-header-end))
@@ -1862,7 +1862,7 @@
     (set-buffer outbuffer)
     (goto-char 1)
     ;; The magic number of .elc files is ";ELC", or 0x3B454C43.  After
     ;; that is the file-format version number (18, 19, 20, or 22) as a
     ;; byte, followed by some nulls.  The primary motivation for doing
     ;; this is to get some binary characters up in the first line of
     ;; the file so that `diff' will simply say "Binary files differ"
@@ -1874,7 +1874,7 @@
 
     (insert
      ";ELC"
-     (if (byte-compile-version-cond byte-compile-compatibility) 18 22)
+     (if (byte-compile-version-cond byte-compile-compatibility) 18 23)
      "\000\000\000\n"
      )
     (insert ";;; Compiled by "
@@ -1862,7 +1862,7 @@
     (goto-char 1)
     ;; The magic number of .elc files is ";ELC", or 0x3B454C43.  After
-    ;; that is the file-format version number (18, 19, 20, or 22) as a
+    ;; that is the file-format version number (18, 19, 20, or 23) as a
     ;; byte, followed by some nulls.  The primary motivation for doing
     ;; this is to get some binary characters up in the first line of